# eventListen

eventListen is a small module for creating events.
eventListen has been designed for the [Trophées NSI 2025](https://trophees-nsi.fr).

## Warning

This package is not maintained and is not intended to be used.